@@ -17,6 +17,8 @@
  * License along with this library; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
  */
+
+#include <wibble/sys/macros.h>
 #include <wibble/exception.h>
 
 #include <string.h> // strerror_r
@@ -27,7 +29,9 @@
 #include <sstream>
 #include <iostream>
 
+#ifdef POSIX
 #include <execinfo.h>
+#endif
 
 using namespace std;
 
@@ -36,6 +40,7 @@ namespace exception {
 
 std::vector< std::string > *AddContext::s_context = 0;
 
+#ifdef POSIX
 void DefaultUnexpected()
 {
 	try {
@@ -60,6 +65,7 @@ void DefaultUnexpected()
 		throw;
 	}
 }
+#endif
 
 InstallUnexpected::InstallUnexpected(void (*func)())
 {
@@ -79,6 +85,7 @@ System::System(const std::string& context) throw ()
 System::System(int code, const std::string& context) throw ()
 	: Generic(context), m_errno(code) {}
 
+#ifdef POSIX
 string System::desc() const throw ()
 {
 	const int buf_size = 500;
@@ -95,7 +102,14 @@ string System::desc() const throw ()
 	return string(strerror_r(m_errno, buf, buf_size));
 #endif
 }
+#endif
 
+#ifdef _WIN32
+string System::desc() const throw ()
+{
+	return strerror(m_errno);
+}
+#endif
 }
 }
 
