@@ -1,5 +1,12 @@
+#include <wibble/sys/macros.h>
+
 #include <wibble/log/ostream.h>
+#ifdef POSIX
 #include <time.h>
+#endif
+#ifdef _WIN32
+#include <ctime>
+#endif
 
 namespace wibble {
 namespace log {
@@ -9,8 +16,15 @@ OstreamSender::OstreamSender(std::ostream& out) : out(out) {}
 void OstreamSender::send(Level level, const std::string& msg)
 {
 	time_t now = time(NULL);
+#ifdef POSIX
 	struct tm pnow;
 	localtime_r(&now, &pnow);
+#endif
+
+#ifdef _WIN32
+	struct tm * pnow;
+	pnow = localtime(&now);
+#endif
 	char timebuf[20];
 	/*
 	 * Strftime specifiers used here:
@@ -20,8 +34,14 @@ void OstreamSender::send(Level level, const std::string& msg)
 	 *			leading zero is replaced by a space. (SU)
 	 *	%T      The time in 24-hour notation (%H:%M:%S). (SU)
 	 */
+#ifdef POSIX
 	strftime(timebuf, 20, "%b %e %T", &pnow);
 	out << timebuf << ": " << msg << std::endl;
+#endif
+
+#ifdef _WIN32
+	out << asctime(pnow) << ": " << msg << std::endl;
+#endif
 	if (level >= WARN)
 		out.flush();
 }
