@@ -1,5 +1,8 @@
 // -*- C++ -*- (c) 2008 Petr Rockai <me@mornfall.net>
 
+#include <wibble/sys/macros.h>
+
+#ifdef POSIX
 #include <fcntl.h>
 #include <sys/select.h>
 
@@ -93,5 +96,5 @@ struct Pipe {
 
 }
 }
-
+#endif
 #endif
