@@ -21,8 +21,16 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
  */
 
+#include <wibble/sys/macros.h>
 #include <wibble/exception.h>
+#ifdef POSIX
 #include <pthread.h>
+#endif
+
+#ifdef _WIN32
+#include <windows.h>
+#include <process.h>
+#endif
 #include <signal.h>
 
 namespace wibble {
@@ -68,7 +76,14 @@ namespace sys {
 class Thread
 {
 protected:
+#ifdef POSIX
 	pthread_t thread;
+#endif
+
+#ifdef _WIN32
+  unsigned int thread;
+  HANDLE hThread;
+#endif
 
 	/**
 	 * Short tag describing this thread, used in error messages and
@@ -83,7 +98,13 @@ protected:
 	virtual void* main() = 0;
 
 	/// Callback function used to start the thread
+#ifdef POSIX
 	static void* Starter(void* parm);
+#endif
+
+#ifdef _WIN32
+  static unsigned __stdcall Starter(void* parm);
+#endif
 
 	void testcancel();
 
