@@ -1,4 +1,7 @@
 // -*- C++ -*-
+#include <wibble/sys/macros.h>
+
+#ifdef POSIX
 #include <unistd.h>
 #include <sys/wait.h>
 #include <cstring>
@@ -228,3 +231,4 @@ struct Main : RunFeedback {
 int main( int argc, char **argv ) {
     return Main().main( argc, argv );
 }
+#endif
